;; This "manifest" file can be passed to 'guix package -m' to reproduce
;; the content of your profile.  This is "symbolic": it only specifies
;; package names.  To reproduce the exact same profile, you also need to
;; capture the channels being used, as returned by "guix describe".
;; See the "Replicating Guix" section in the manual.

(use-modules
 (gnu)
 (guix profiles)
 (guix packages)
 (guix git-download)
 (guix build-system python)
 ((guix licenses) #:prefix license:))

(use-package-modules
 python-xyz
 freedesktop
 python-build
 admin
 python-crypto
 openldap
 version-control
 tls
 python
 gnupg)

(packages->manifest
 (list
  git
  git-crypt
  gnupg
  openssl
  python
  (package
    (name "debops")
    (version "3.0.2")
    (source (origin
              (method git-fetch)
              (uri (git-reference
                    (url "https://github.com/debops/debops")
                    (commit (string-append "v" version))))
              (file-name (git-file-name name version))
              (sha256
               (base32
                "05m9i17hyiz4mm3d1h9zi7j4gid69j08p2yg7zqpaxmby2sbnncf"))))
    (build-system python-build-system)
    (native-inputs (list git))
    (propagated-inputs (list python-distro
                             python-future
                             python-jinja2
                             python-pyyaml
                             python-pyxdg
                             python-toml
                             python-dotenv
                             ansible
                             python-netaddr
                             python-passlib
                             python-ldap
                             python-dnspython
                             python-pyopenssl))
    (arguments
     `(#:phases (modify-phases %standard-phases
                  ;; Patching shebangs breaks scripts that are meant to be
                  ;; deployed to other systems and there are no scripts that
                  ;; do need patching.
                  (delete 'patch-source-shebangs)
                  (delete 'patch-generated-file-shebangs))))
    (home-page "https://www.debops.org/")
    (synopsis "Collection of general-purpose Ansible roles")
    (description
     "The Ansible roles provided by that can be used to manage Debian or
Ubuntu hosts.  In addition, a default set of Ansible playbooks can be used to
apply the provided roles in a controlled way, using Ansible inventory groups.

The roles are written with a high customization in mind, which can be done
using Ansible inventory.  This way the role and playbook code can be shared
between multiple environments, with different configuration in to each one.

Services can be managed on a single host, or spread between multiple hosts.
DebOps provides support for different SQL and NoSQL databases, web servers,
programming languages and specialized applications useful in a data center
environment or in a cluster.  The project can also be used to deploy
virtualization environments using KVM/libvirt, Docker or LXC technologies to
manage virtual machines and/or containers.")
    (license license:gpl3+))))
